@@ -35,6 +35,10 @@
 #include <netinet/tcp.h>
 #include <netinet/ip_icmp.h>
 #include <netinet/igmp.h>
+#if defined(RAIN_IPV6)
+  #include <netinet/ip6.h>
+  #include <netinet/icmp6.h>
+#endif
 #include <arpa/inet.h>
 #include <netdb.h>
 
@@ -43,13 +47,16 @@
 #include "rain_tcp.h"
 #include "rain_udp.h"
 #include "rain_icmp.h"
+#if defined(RAIN_IPV6)
+  #include "rain_icmp6.h"
+#endif
 #include "rain_igmp.h"
 #include "rain_die.h"
 #include "rain_resolv.h"
 #include "rain_signal.h"
 #include "rain_string.h"
 
-#define RAIN_VERSION "1.2.2"
+#define RAIN_VERSION "1.2.4"
 
 #define TRUE  (1)
 #define FALSE (0)
